<?php
/**
 * Indoor Sports Zone functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Indoor Sports Zone
 */

include get_theme_file_path( 'vendor/wptrt/autoload/src/Indoor_Sports_Zone_Loader.php' );

$Indoor_Sports_Zone_Loader = new \WPTRT\Autoload\Indoor_Sports_Zone_Loader();

$Indoor_Sports_Zone_Loader->indoor_sports_zone_add( 'WPTRT\\Customize\\Section', get_theme_file_path( 'vendor/wptrt/customize-section-button/src' ) );

$Indoor_Sports_Zone_Loader->indoor_sports_zone_register();

if ( ! function_exists( 'indoor_sports_zone_setup' ) ) :

	function indoor_sports_zone_setup() {

		/*
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		*/
		add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

		load_theme_textdomain( 'indoor-sports-zone', get_template_directory() . '/languages' );
		add_theme_support( 'woocommerce' );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "align-wide" );
		add_theme_support( "wp-block-styles" );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
        add_image_size('indoor-sports-zone-featured-header-image', 2000, 660, true);

        register_nav_menus( array(
            'primary' => esc_html__( 'Primary','indoor-sports-zone' ),
	        'footer'=> esc_html__( 'Footer Menu','indoor-sports-zone' ),
        ) );

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'custom-background', apply_filters( 'indoor_sports_zone_custom_background_args', array(
			'default-color' => 'f7ebe5',
			'default-image' => '',
		) ) );

		add_theme_support( 'customize-selective-refresh-widgets' );

		add_theme_support( 'custom-logo', array(
			'height'      => 80,
			'width'       => 80,
			'flex-width'  => true,
		) );

		add_editor_style( array( '/editor-style.css' ) );
		add_action('wp_ajax_indoor_sports_zone_dismissable_notice', 'indoor_sports_zone_dismissable_notice');
	}
endif;
add_action( 'after_setup_theme', 'indoor_sports_zone_setup' );


function indoor_sports_zone_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'indoor_sports_zone_content_width', 1170 );
}
add_action( 'after_setup_theme', 'indoor_sports_zone_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function indoor_sports_zone_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'indoor-sports-zone' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'indoor-sports-zone' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 1', 'indoor-sports-zone' ),
		'id'            => 'indoor-sports-zone-footer1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 2', 'indoor-sports-zone' ),
		'id'            => 'indoor-sports-zone-footer2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 3', 'indoor-sports-zone' ),
		'id'            => 'indoor-sports-zone-footer3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'indoor_sports_zone_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function indoor_sports_zone_scripts() {

	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );

	wp_enqueue_style(
		'inter',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Inter:wght@100..900&display=swap' ),
		array(),
		'1.0'
	);

	wp_enqueue_style(
		'jomhuria',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Jomhuria&display=swap' ),
		array(),
		'1.0'
	);

	wp_enqueue_style(
		'work-sans',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Work+Sans:ital,wght@0,100..900;1,100..900&display=swap' ),
		array(),
		'1.0'
	);

	wp_enqueue_style( 'indoor-sports-zone-block-editor-style', get_theme_file_uri('/assets/css/block-editor-style.css') );

	// load bootstrap css
    wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/assets/css/bootstrap.min.css');

    wp_enqueue_style( 'owl.carousel-css', get_template_directory_uri() . '/assets/css/owl.carousel.css');

	wp_enqueue_style( 'indoor-sports-zone-style', get_stylesheet_uri() );
	require get_parent_theme_file_path( '/custom-option.php' );
	wp_add_inline_style( 'indoor-sports-zone-style',$indoor_sports_zone_theme_css );

	// fontawesome
	wp_enqueue_style( 'fontawesome-style', get_template_directory_uri() .'/assets/css/fontawesome/css/all.css' );

    wp_enqueue_script('indoor-sports-zone-theme-js', get_template_directory_uri() . '/assets/js/theme-script.js', array('jquery'), '', true );

    wp_enqueue_script('owl.carousel-js', get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'), '', true );

    wp_enqueue_script('bootstrap-min-js', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), '', true );
    

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'indoor_sports_zone_scripts' );

/**
 * Enqueue Preloader.
 */
function indoor_sports_zone_preloader() {

	$indoor_sports_zone_theme_color_css = '';
	$indoor_sports_zone_preloader_bg_color = get_theme_mod('indoor_sports_zone_preloader_bg_color');
	$indoor_sports_zone_preloader_dot_1_color = get_theme_mod('indoor_sports_zone_preloader_dot_1_color');
	$indoor_sports_zone_preloader_dot_2_color = get_theme_mod('indoor_sports_zone_preloader_dot_2_color');
	$indoor_sports_zone_scroll_bg_color = get_theme_mod('indoor_sports_zone_scroll_bg_color');
	$indoor_sports_zone_scroll_color = get_theme_mod('indoor_sports_zone_scroll_color');
	$indoor_sports_zone_scroll_font_size = get_theme_mod('indoor_sports_zone_scroll_font_size');
	$indoor_sports_zone_scroll_border_radius = get_theme_mod('indoor_sports_zone_scroll_border_radius');

	if(get_theme_mod('indoor_sports_zone_preloader_bg_color') == '') {
		$indoor_sports_zone_preloader_bg_color = '#0BB640';
	}
	if(get_theme_mod('indoor_sports_zone_preloader_dot_1_color') == '') {
		$indoor_sports_zone_preloader_dot_1_color = '#ffffff';
	}
	if(get_theme_mod('indoor_sports_zone_preloader_dot_2_color') == '') {
		$indoor_sports_zone_preloader_dot_2_color = '#000000';
	}
	$indoor_sports_zone_theme_color_css = '
		.loading{
			background-color: '.esc_attr($indoor_sports_zone_preloader_bg_color).';
		 }
		 @keyframes loading {
		  0%,
		  100% {
		  	transform: translatey(-2.5rem);
		    background-color: '.esc_attr($indoor_sports_zone_preloader_dot_1_color).';
		  }
		  50% {
		  	transform: translatey(2.5rem);
		    background-color: '.esc_attr($indoor_sports_zone_preloader_dot_2_color).';
		  }
		}
		a#button{
			background-color: '.esc_attr($indoor_sports_zone_scroll_bg_color).';
			color: '.esc_attr($indoor_sports_zone_scroll_color).' !important;
			font-size: '.esc_attr($indoor_sports_zone_scroll_font_size).'px;
			border-radius: '.esc_attr($indoor_sports_zone_scroll_border_radius).'%;
		}
	';
    wp_add_inline_style( 'indoor-sports-zone-style',$indoor_sports_zone_theme_color_css );

}
add_action( 'wp_enqueue_scripts', 'indoor_sports_zone_preloader' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

function indoor_sports_zone_sanitize_select( $input, $setting ){
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

function indoor_sports_zone_sanitize_checkbox( $input ) {
  // Boolean check
  return ( ( isset( $input ) && true == $input ) ? true : false );
}

/*radio button sanitization*/
function indoor_sports_zone_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function indoor_sports_zone_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}


// Change number or products per row to 3
add_filter('loop_shop_columns', 'indoor_sports_zone_loop_columns');
if (!function_exists('indoor_sports_zone_loop_columns')) {
	function indoor_sports_zone_loop_columns() {
		$indoor_sports_zone_columns = get_theme_mod( 'indoor_sports_zone_products_per_row', 3 );
		return $indoor_sports_zone_columns; // 3 products per row
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'indoor_sports_zone_shop_per_page', 9 );
function indoor_sports_zone_shop_per_page( $cols ) {
  	$cols = get_theme_mod( 'indoor_sports_zone_product_per_page', 9 );
	return $cols;
}

function indoor_sports_zone_remove_customize_register() {
    global $wp_customize;

    $wp_customize->remove_setting( 'pro_version_footer' );
    $wp_customize->remove_control( 'pro_version_footer' );

}
add_action( 'customize_register', 'indoor_sports_zone_remove_customize_register', 11 );

/**
 * Get CSS
 */

function indoor_sports_zone_getpage_css($hook) {
	wp_register_script( 'admin-notice-script', get_template_directory_uri() . '/inc/admin/js/admin-notice-script.js', array( 'jquery' ) );
   	wp_localize_script('admin-notice-script','indoor_sports_zone',
		array('admin_ajax'	=>	admin_url('admin-ajax.php'),'wpnonce'  =>	wp_create_nonce('indoor_sports_zone_dismissed_notice_nonce')
		)
	);
	wp_enqueue_script('admin-notice-script');

    wp_localize_script( 'admin-notice-script', 'indoor_sports_zone_ajax_object',
        array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
    );
	if ( 'appearance_page_indoor-sports-zone-info' != $hook ) {
		return;
	}
	wp_enqueue_style( 'indoor-sports-zone-demo-style', get_template_directory_uri() . '/assets/css/demo.css' );
}
add_action( 'admin_enqueue_scripts', 'indoor_sports_zone_getpage_css' );

if ( ! defined( 'INDOOR_SPORTS_ZONE_CONTACT_SUPPORT' ) ) {
define('INDOOR_SPORTS_ZONE_CONTACT_SUPPORT',__('https://wordpress.org/support/theme/indoor-sports-zone/','indoor-sports-zone'));
}
if ( ! defined( 'INDOOR_SPORTS_ZONE_REVIEW' ) ) {
define('INDOOR_SPORTS_ZONE_REVIEW',__('https://wordpress.org/support/theme/indoor-sports-zone/reviews/','indoor-sports-zone'));
}
if ( ! defined( 'INDOOR_SPORTS_ZONE_LIVE_DEMO' ) ) {
define('INDOOR_SPORTS_ZONE_LIVE_DEMO',__('https://demo.themagnifico.net/indoor-sports-zone/','indoor-sports-zone'));
}
if ( ! defined( 'INDOOR_SPORTS_ZONE_GET_PREMIUM_PRO' ) ) {
define('INDOOR_SPORTS_ZONE_GET_PREMIUM_PRO',__('https://www.themagnifico.net/products/indoor-sports-wordpress-theme/','indoor-sports-zone'));
}
if ( ! defined( 'INDOOR_SPORTS_ZONE_PRO_DOC' ) ) {
define('INDOOR_SPORTS_ZONE_PRO_DOC',__('https://demo.themagnifico.net/eard/wathiqa/indoor-sports-zone-pro-doc/','indoor-sports-zone'));
}
if ( ! defined( 'INDOOR_SPORTS_ZONE_PRO_FREE_DOC' ) ) {
define('INDOOR_SPORTS_ZONE_PRO_FREE_DOC',__('https://demo.themagnifico.net/eard/wathiqa/indoor-sports-zone-free-doc/','indoor-sports-zone'));
}

add_action('admin_menu', 'indoor_sports_zone_themepage');
function indoor_sports_zone_themepage(){

	$indoor_sports_zone_theme_test = wp_get_theme();

	$indoor_sports_zone_theme_info = add_theme_page( __('Theme Options','indoor-sports-zone'), __(' Theme Options','indoor-sports-zone'), 'manage_options', 'indoor-sports-zone-info.php', 'indoor_sports_zone_info_page' );
}

function indoor_sports_zone_info_page() {
	$indoor_sports_zone_theme_user = wp_get_current_user();
	$indoor_sports_zone_theme = wp_get_theme();
	?>
	<div class="wrap about-wrap indoor-sports-zone-add-css">
		<div>
			<h1>
				<?php esc_html_e('Welcome To ','indoor-sports-zone'); ?><?php echo esc_html( $indoor_sports_zone_theme ); ?>
			</h1>
			<div class="feature-section three-col">
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Contact Support", "indoor-sports-zone"); ?></h3>
						<p><?php esc_html_e("Thank you for trying Indoor Sports Zone , feel free to contact us for any support regarding our theme.", "indoor-sports-zone"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_CONTACT_SUPPORT ); ?>" class="button button-primary get">
							<?php esc_html_e("Contact Support", "indoor-sports-zone"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Checkout Premium", "indoor-sports-zone"); ?></h3>
						<p><?php esc_html_e("Our premium theme comes with extended features like demo content import , responsive layouts etc.", "indoor-sports-zone"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_GET_PREMIUM_PRO ); ?>" class="button button-primary get prem">
							<?php esc_html_e("Get Premium", "indoor-sports-zone"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Review", "indoor-sports-zone"); ?></h3>
						<p><?php esc_html_e("If You love Indoor Sports Zone theme then we would appreciate your review about our theme.", "indoor-sports-zone"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_REVIEW ); ?>" class="button button-primary get">
							<?php esc_html_e("Review", "indoor-sports-zone"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Free Documentation", "indoor-sports-zone"); ?></h3>
						<p><?php esc_html_e("Our guide is available if you require any help configuring and setting up the theme. Easy and quick way to setup the theme.", "indoor-sports-zone"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_PRO_FREE_DOC ); ?>" class="button button-primary get">
							<?php esc_html_e("Free Documentation", "indoor-sports-zone"); ?>
						</a></p>
					</div>
				</div>
			</div>
		</div>
		<hr>

		<h2><?php esc_html_e("Free Vs Premium","indoor-sports-zone"); ?></h2>
		<div class="indoor-sports-zone-button-container">
			<a target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_PRO_DOC ); ?>" class="button button-primary get">
				<?php esc_html_e("Checkout Documentation", "indoor-sports-zone"); ?>
			</a>
			<a target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_LIVE_DEMO ); ?>" class="button button-primary get">
				<?php esc_html_e("View Theme Demo", "indoor-sports-zone"); ?>
			</a>
		</div>

		<table class="wp-list-table widefat">
			<thead class="table-book">
				<tr>
					<th><strong><?php esc_html_e("Theme Feature", "indoor-sports-zone"); ?></strong></th>
					<th><strong><?php esc_html_e("Basic Version", "indoor-sports-zone"); ?></strong></th>
					<th><strong><?php esc_html_e("Premium Version", "indoor-sports-zone"); ?></strong></th>
				</tr>
			</thead>

			<tbody>
				<tr>
					<td><?php esc_html_e("Header Background Color", "indoor-sports-zone"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Navigation Logo Or Text", "indoor-sports-zone"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Hide Logo Text", "indoor-sports-zone"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Premium Support", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Fully SEO Optimized", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Recent Posts Widget", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Easy Google Fonts", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Pagespeed Plugin", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Header Image On Front Page", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Show Header Everywhere", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Text On Header Image", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Full Width (Hide Sidebar)", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Upper Widgets On Front Page", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Replace Copyright Text", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Upper Widgets Colors", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Navigation Color", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Post/Page Color", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Blog Feed Color", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Footer Color", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Sidebar Color", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Background Color", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Importable Demo Content	", "indoor-sports-zone"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
			</tbody>
		</table>
		<div class="indoor-sports-zone-button-container">
			<a target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_GET_PREMIUM_PRO ); ?>" class="button button-primary get prem">
				<?php esc_html_e("Go Premium", "indoor-sports-zone"); ?>
			</a>
		</div>
	</div>
	<?php
}

//Admin Notice For Getstart
function indoor_sports_zone_ajax_notice_handler() {
	if (!wp_verify_nonce($_POST['wpnonce'], 'indoor_sports_zone_dismissed_notice_nonce')) {
		exit;
	}
    if ( isset( $_POST['type'] ) ) {
        $type = sanitize_text_field( wp_unslash( $_POST['type'] ) );
        update_option( 'dismissed-' . $type, TRUE );
    }
}
add_action( 'wp_ajax_indoor_sports_zone_dismissed_notice_handler', 'indoor_sports_zone_ajax_notice_handler' );

function indoor_sports_zone_deprecated_hook_admin_notice() {

    $indoor_sports_zone_dismissed = get_user_meta(get_current_user_id(), 'indoor_sports_zone_dismissable_notice', true);
    if ( !$indoor_sports_zone_dismissed) { ?>
        <div class="updated notice notice-success is-dismissible notice-get-started-class" data-notice="get_started" style="background: #f7f9f9; padding: 20px 10px; display: flex;">
	    	<div class="tm-admin-image">
	    		<img style="width: 100%;max-width: 320px;line-height: 40px;display: inline-block;vertical-align: top;border: 2px solid #ddd;border-radius: 4px;" src="<?php echo esc_url(get_stylesheet_directory_uri()) .'/screenshot.png'; ?>" />
	    	</div>
	    	<div class="tm-admin-content" style="padding-left: 30px; align-self: center">
	    		<h2 style="font-weight: 600;line-height: 1.3; margin: 0px;"><?php esc_html_e('Thank You For Choosing ', 'indoor-sports-zone'); ?><?php echo wp_get_theme(); ?><h2>
	    		<p style="color: #3c434a; font-weight: 400; margin-bottom: 30px;"><?php _e('Get Started With Theme By Clicking On Getting Started.', 'indoor-sports-zone'); ?><p>
	        	<a class="admin-notice-btn button button-primary button-hero" href="<?php echo esc_url( admin_url( 'themes.php?page=indoor-sports-zone-info.php' )); ?>"><?php esc_html_e( 'Get started', 'indoor-sports-zone' ) ?></a>
	        	<a class="admin-notice-btn button button-primary button-hero" target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_PRO_FREE_DOC ); ?>"><?php esc_html_e( 'Documentation', 'indoor-sports-zone' ) ?></a>
	        	<span style="padding-top: 15px; display: inline-block; padding-left: 8px;">
	        	<span class="dashicons dashicons-admin-links"></span>
	        	<a class="admin-notice-btn"	 target="_blank" href="<?php echo esc_url( INDOOR_SPORTS_ZONE_LIVE_DEMO ); ?>"><?php esc_html_e( 'View Demo', 'indoor-sports-zone' ) ?></a>
	        	</span>
	    	</div>
        </div>
    <?php }
}

add_action( 'admin_notices', 'indoor_sports_zone_deprecated_hook_admin_notice' );

function indoor_sports_zone_switch_theme() {
    delete_user_meta(get_current_user_id(), 'indoor_sports_zone_dismissable_notice');
}
add_action('after_switch_theme', 'indoor_sports_zone_switch_theme');
function indoor_sports_zone_dismissable_notice() {
    update_user_meta(get_current_user_id(), 'indoor_sports_zone_dismissable_notice', true);
    die();
}
