<?php
/**
 * Indoor Sports Zone Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Indoor Sports Zone
 */

if ( ! defined( 'INDOOR_SPORTS_ZONE_URL' ) ) {
    define( 'INDOOR_SPORTS_ZONE_URL', esc_url( 'https://www.themagnifico.net/products/indoor-sports-wordpress-theme/', 'indoor-sports-zone') );
}
if ( ! defined( 'INDOOR_SPORTS_ZONE_TEXT' ) ) {
    define( 'INDOOR_SPORTS_ZONE_TEXT', __( 'Indoor Sports Zone Pro','indoor-sports-zone' ));
}
if ( ! defined( 'INDOOR_SPORTS_ZONE_BUY_TEXT' ) ) {
    define( 'INDOOR_SPORTS_ZONE_BUY_TEXT', __( 'Buy Indoor Sports Zone Pro','indoor-sports-zone' ));
}

use WPTRT\Customize\Section\Indoor_Sports_Zone_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Indoor_Sports_Zone_Button::class );

    $manager->add_section(
        new Indoor_Sports_Zone_Button( $manager, 'indoor_sports_zone_pro', [
            'title'       => esc_html( INDOOR_SPORTS_ZONE_TEXT,'indoor-sports-zone' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'indoor-sports-zone' ),
            'button_url'  => esc_url( INDOOR_SPORTS_ZONE_URL )
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'indoor-sports-zone-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'indoor-sports-zone-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function indoor_sports_zone_customize_register($wp_customize){

    // Pro Version
    class Indoor_Sports_Zone_Customize_Pro_Version extends WP_Customize_Control {
        public $type = 'pro_options';

        public function render_content() {
            echo '<span>' . esc_html('For More','indoor-sports-zone') . ' <strong>' . esc_html($this->label) . '</strong>?</span>';
            echo '<a href="'. esc_url($this->description) .'" target="_blank">';
                echo '<span class="dashicons dashicons-info"></span>';
                echo '<strong> '. esc_html( INDOOR_SPORTS_ZONE_BUY_TEXT) .'<strong></a>';
            echo '</a>';
        }
    }

    // Custom Controls
    function Indoor_Sports_Zone_sanitize_custom_control( $input ) {
        return $input;
    }

    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    $wp_customize->add_setting('indoor_sports_zone_logo_title_text', array(
        'default' => true,
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'indoor_sports_zone_logo_title_text',array(
        'label'          => __( 'Enable Disable Title', 'indoor-sports-zone' ),
        'section'        => 'title_tagline',
        'settings'       => 'indoor_sports_zone_logo_title_text',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('indoor_sports_zone_theme_description', array(
        'default' => false,
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'indoor_sports_zone_theme_description',array(
        'label'          => __( 'Enable Disable Tagline', 'indoor-sports-zone' ),
        'section'        => 'title_tagline',
        'settings'       => 'indoor_sports_zone_theme_description',
        'type'           => 'checkbox',
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_logo', array(
        'sanitize_callback' => 'Indoor_Sports_Zone_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Indoor_Sports_Zone_Customize_Pro_Version ( $wp_customize,'pro_version_logo', array(
        'section'     => 'title_tagline',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'indoor-sports-zone' ),
        'description' => esc_url( INDOOR_SPORTS_ZONE_URL ),
        'priority'    => 100
    )));

    // Global Color Settings
     $wp_customize->add_section('indoor_sports_zone_global_color_settings',array(
        'title' => esc_html__('Global Color Settings','indoor-sports-zone'),
        'priority'   => 28,
    ));

     $wp_customize->add_setting( 'indoor_sports_zone_global_color', array(
        'default' => '#0BB640',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'indoor_sports_zone_global_color', array(
        'description' => __('Change the global color of the theme in one click.', 'indoor-sports-zone'),
        'section' => 'indoor_sports_zone_global_color_settings',
        'settings' => 'indoor_sports_zone_global_color',
    )));

    // General Settings
     $wp_customize->add_section('indoor_sports_zone_general_settings',array(
        'title' => esc_html__('General Settings','indoor-sports-zone'),
        'priority'   => 30,
    ));

    $wp_customize->add_setting('indoor_sports_zone_width_option',array(
        'default' => 'Full Width',
        'transport' => 'refresh',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_width_option',array(
        'type' => 'select',
        'section' => 'indoor_sports_zone_general_settings',
        'choices' => array(
            'Full Width' => __('Full Width','indoor-sports-zone'),
            'Wide Width' => __('Wide Width','indoor-sports-zone'),
            'Boxed Width' => __('Boxed Width','indoor-sports-zone')
        ),
    ) );

    $wp_customize->add_setting('indoor_sports_zone_nav_menu_text_transform',array(
        'default'=> 'Capitalize',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_nav_menu_text_transform',array(
        'type' => 'radio',
        'choices' => array(
            'Uppercase' => __('Uppercase','indoor-sports-zone'),
            'Capitalize' => __('Capitalize','indoor-sports-zone'),
            'Lowercase' => __('Lowercase','indoor-sports-zone'),
        ),
        'section'=> 'indoor_sports_zone_general_settings',
    ));

    $wp_customize->add_setting('indoor_sports_zone_preloader_hide', array(
        'default' => 0,
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'indoor_sports_zone_preloader_hide',array(
        'label'          => __( 'Show Theme Preloader', 'indoor-sports-zone' ),
        'section'        => 'indoor_sports_zone_general_settings',
        'settings'       => 'indoor_sports_zone_preloader_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting( 'indoor_sports_zone_preloader_bg_color', array(
        'default' => '#0BB640',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'indoor_sports_zone_preloader_bg_color', array(
        'label' => esc_html__('Preloader Background Color','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_general_settings',
        'settings' => 'indoor_sports_zone_preloader_bg_color'
    )));

    $wp_customize->add_setting( 'indoor_sports_zone_preloader_dot_1_color', array(
        'default' => '#ffffff',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'indoor_sports_zone_preloader_dot_1_color', array(
        'label' => esc_html__('Preloader First Dot Color','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_general_settings',
        'settings' => 'indoor_sports_zone_preloader_dot_1_color'
    )));

    $wp_customize->add_setting( 'indoor_sports_zone_preloader_dot_2_color', array(
        'default' => '#000000',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'indoor_sports_zone_preloader_dot_2_color', array(
        'label' => esc_html__('Preloader Second Dot Color','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_general_settings',
        'settings' => 'indoor_sports_zone_preloader_dot_2_color'
    )));

    $wp_customize->add_setting('indoor_sports_zone_scroll_hide', array(
        'default' => false,
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'indoor_sports_zone_scroll_hide',array(
        'label'          => __( 'Show Theme Scroll To Top', 'indoor-sports-zone' ),
        'section'        => 'indoor_sports_zone_general_settings',
        'settings'       => 'indoor_sports_zone_scroll_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('indoor_sports_zone_scroll_top_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_scroll_top_position',array(
        'type' => 'radio',
        'label' => esc_html__('Scroll To Top Position','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_general_settings',
        'choices' => array(
            'Right' => __('Right','indoor-sports-zone'),
            'Left' => __('Left','indoor-sports-zone'),
            'Center' => __('Center','indoor-sports-zone')
        ),
    ) );

    $wp_customize->add_setting( 'indoor_sports_zone_scroll_bg_color', array(
        'default' => '',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'indoor_sports_zone_scroll_bg_color', array(
        'label' => esc_html__('Scroll Top Background Color','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_general_settings',
        'settings' => 'indoor_sports_zone_scroll_bg_color'
    )));

    $wp_customize->add_setting( 'indoor_sports_zone_scroll_color', array(
        'default' => '',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'indoor_sports_zone_scroll_color', array(
        'label' => esc_html__('Scroll Top Color','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_general_settings',
        'settings' => 'indoor_sports_zone_scroll_color'
    )));

    $wp_customize->add_setting('indoor_sports_zone_scroll_font_size',array(
        'default'   => '16',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('indoor_sports_zone_scroll_font_size',array(
        'label' => __('Scroll Top Font Size','indoor-sports-zone'),
        'description' => __('Put in px','indoor-sports-zone'),
        'section'   => 'indoor_sports_zone_general_settings',
        'type'      => 'number'
    ));

    $wp_customize->add_setting('indoor_sports_zone_scroll_border_radius',array(
        'default'   => '0',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('indoor_sports_zone_scroll_border_radius',array(
        'label' => __('Scroll Top Border Radius','indoor-sports-zone'),
        'description' => __('Put in %','indoor-sports-zone'),
        'section'   => 'indoor_sports_zone_general_settings',
        'type'      => 'number'
    ));

    // Product Columns
    $wp_customize->add_setting( 'indoor_sports_zone_products_per_row' , array(
       'default'           => '3',
       'transport'         => 'refresh',
       'sanitize_callback' => 'indoor_sports_zone_sanitize_select',
    ) );

    $wp_customize->add_control('indoor_sports_zone_products_per_row', array(
       'label' => __( 'Product per row', 'indoor-sports-zone' ),
       'section'  => 'indoor_sports_zone_general_settings',
       'type'     => 'select',
       'choices'  => array(
           '2' => '2',
           '3' => '3',
           '4' => '4',
       ),
    ) );

    $wp_customize->add_setting('indoor_sports_zone_product_per_page',array(
        'default'   => '9',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('indoor_sports_zone_product_per_page',array(
        'label' => __('Product per page','indoor-sports-zone'),
        'section'   => 'indoor_sports_zone_general_settings',
        'type'      => 'number'
    ));

    //Woocommerce shop page Sidebar
    $wp_customize->add_setting('indoor_sports_zone_woocommerce_shop_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'indoor_sports_zone_woocommerce_shop_page_sidebar',array(
        'label'          => __( 'Hide Shop Page Sidebar', 'indoor-sports-zone' ),
        'section'        => 'indoor_sports_zone_general_settings',
        'settings'       => 'indoor_sports_zone_woocommerce_shop_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('indoor_sports_zone_shop_page_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_shop_page_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Shop Page Sidebar','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','indoor-sports-zone'),
            'Right Sidebar' => __('Right Sidebar','indoor-sports-zone'),
        ),
    ) );

    //Woocommerce Single Product page Sidebar
    $wp_customize->add_setting('indoor_sports_zone_woocommerce_single_product_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'indoor_sports_zone_woocommerce_single_product_page_sidebar',array(
        'label'          => __( 'Hide Single Product Page Sidebar', 'indoor-sports-zone' ),
        'section'        => 'indoor_sports_zone_general_settings',
        'settings'       => 'indoor_sports_zone_woocommerce_single_product_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('indoor_sports_zone_single_product_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_single_product_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Single Product Page Sidebar','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','indoor-sports-zone'),
            'Right Sidebar' => __('Right Sidebar','indoor-sports-zone'),
        ),
    ) );

    // Pro Version
    $wp_customize->add_setting( 'pro_version_general_setting', array(
        'sanitize_callback' => 'Indoor_Sports_Zone_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Indoor_Sports_Zone_Customize_Pro_Version ( $wp_customize,'pro_version_general_setting', array(
        'section'     => 'indoor_sports_zone_general_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'indoor-sports-zone' ),
        'description' => esc_url( INDOOR_SPORTS_ZONE_URL ),
        'priority'    => 100
    )));

    // Header
    $wp_customize->add_section('indoor_sports_zone_header_settings',array(
        'title' => esc_html__('Header Settings','indoor-sports-zone'),
    ));

    $wp_customize->add_setting('indoor_sports_zone_header_button_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('indoor_sports_zone_header_button_text',array(
        'label' => __('Button Text','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_header_settings',
        'setting' => 'indoor_sports_zone_header_button_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('indoor_sports_zone_header_button_url',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('indoor_sports_zone_header_button_url',array(
        'label' => __('Button Url','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_header_settings',
        'setting' => 'indoor_sports_zone_header_button_url',
        'type'  => 'url'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_header_setting', array(
        'sanitize_callback' => 'Indoor_Sports_Zone_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Indoor_Sports_Zone_Customize_Pro_Version ( $wp_customize,'pro_version_header_setting', array(
        'section'     => 'indoor_sports_zone_header_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'indoor-sports-zone' ),
        'description' => esc_url( INDOOR_SPORTS_ZONE_URL ),
        'priority'    => 100
    )));

    //Slider
    $wp_customize->add_section('indoor_sports_zone_top_slider',array(
        'title' => esc_html__('Slider Settings','indoor-sports-zone'),
    ));

    $wp_customize->add_setting('indoor_sports_zone_slider_number', array(
        'default'            => '',
        'sanitize_callback'  => 'absint', // Sanitize as an integer
    ));

    $wp_customize->add_control('indoor_sports_zone_slider_number', array(
        'label'    => __('Number of Sliders', 'indoor-sports-zone'),
        'section'  => 'indoor_sports_zone_top_slider',
        'settings' => 'indoor_sports_zone_slider_number',
        'description'   => esc_html__( 'You can enter any number from 1 to 5. To view the slider settings, first enter the slider count and then reload the Customizer', 'indoor-sports-zone' ),
        'type'     => 'number',
        'input_attrs' => array(
            'min'  => 1,
            'max'  => 5,
        ),
    ));

    $indoor_sports_zone_number = get_theme_mod('indoor_sports_zone_slider_number');

    for($i=1; $i<=$indoor_sports_zone_number;$i++ ){

        $wp_customize->add_setting('indoor_sports_zone_slide_image'.$i,array(
            'default' => '',
            'sanitize_callback' => 'esc_url_raw',
        ));
        $wp_customize->add_control(
            new WP_Customize_Image_Control( $wp_customize,'indoor_sports_zone_slide_image'.$i,array(
            'label' => __('Slider Image ','indoor-sports-zone').$i,
            'description' => __('Slider image size (1400 x 600)','indoor-sports-zone'),
            'section' => 'indoor_sports_zone_top_slider',
            'settings' => 'indoor_sports_zone_slide_image'.$i
        )));

        $wp_customize->add_setting('indoor_sports_zone_slide_sub_heading'.$i,array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control('indoor_sports_zone_slide_sub_heading'.$i,array(
            'label'   => __('Slider Short Heading ','indoor-sports-zone') .$i,
            'section' => 'indoor_sports_zone_top_slider',
            'setting' => 'indoor_sports_zone_slide_sub_heading'.$i,
            'type'    => 'text'
        ));

        $wp_customize->add_setting('indoor_sports_zone_slide_heading'.$i,array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control('indoor_sports_zone_slide_heading'.$i,array(
            'label'   => __('slider Heading ','indoor-sports-zone').$i,
            'section' => 'indoor_sports_zone_top_slider',
            'setting' => 'indoor_sports_zone_slide_heading'.$i,
            'type'    => 'text'
        ));

        $wp_customize->add_setting('indoor_sports_zone_slide_text'.$i,array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control('indoor_sports_zone_slide_text'.$i,array(
            'label' => __('Slider Content ','indoor-sports-zone').$i,
            'section' => 'indoor_sports_zone_top_slider',
            'setting' => 'indoor_sports_zone_slide_text'.$i,
            'type'    => 'text'
        ));

        $wp_customize->add_setting('indoor_sports_zone_slide_btntext'.$i,array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control('indoor_sports_zone_slide_btntext'.$i,array(
            'label' => __('Slider Button Text ','indoor-sports-zone').$i,
            'section' => 'indoor_sports_zone_top_slider',
            'setting' => 'indoor_sports_zone_slide_btntext'.$i,
            'type'    => 'text'
        ));

        $wp_customize->add_setting('indoor_sports_zone_slide_btnurl'.$i,array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control('indoor_sports_zone_slide_btnurl'.$i,array(
            'label' => __('Slider Button Url ','indoor-sports-zone').$i,
            'section' => 'indoor_sports_zone_top_slider',
            'setting' => 'indoor_sports_zone_slide_btnurl'.$i,
            'type'    => 'url'
        ));

        $wp_customize->add_setting('indoor_sports_zone_slide_image_title'.$i,array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control('indoor_sports_zone_slide_image_title'.$i,array(
            'label' => __('Slider Small Image Title ','indoor-sports-zone').$i,
            'section' => 'indoor_sports_zone_top_slider',
            'setting' => 'indoor_sports_zone_slide_image_title'.$i,
            'type'    => 'text'
        )); 
    }

    // Pro Version
    $wp_customize->add_setting( 'indoor_sports_zone_slider_setting', array(
        'sanitize_callback' => 'Indoor_Sports_Zone_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Indoor_Sports_Zone_Customize_Pro_Version ( $wp_customize,'indoor_sports_zone_slider_setting', array(
        'section'     => 'indoor_sports_zone_top_slider',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'indoor-sports-zone' ),
        'description' => esc_url( INDOOR_SPORTS_ZONE_URL ),
        'priority'    => 100
    )));

    // Services
    $wp_customize->add_section('indoor_sports_zone_services_section',array(
        'title' => esc_html__('Services Option','indoor-sports-zone'),
    ));

    $wp_customize->add_setting('indoor_sports_zone_about_section_setting', array(
        'default' => 0,
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'indoor_sports_zone_about_section_setting',array(
        'label'          => __( 'Enable Disable Services', 'indoor-sports-zone' ),
        'section'        => 'indoor_sports_zone_services_section',
        'settings'       => 'indoor_sports_zone_about_section_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('indoor_sports_zone_services_short_heading',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('indoor_sports_zone_services_short_heading',array(
        'label' => esc_html__('Short Heading','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_services_section',
        'setting' => 'indoor_sports_zone_services_short_heading',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('indoor_sports_zone_services_image_heading',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('indoor_sports_zone_services_image_heading',array(
        'label' => esc_html__('Main Heading','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_services_section',
        'setting' => 'indoor_sports_zone_services_image_heading',
        'type'  => 'text'
    ));

    $categories = get_categories();
    $cat_post = array();
    $cat_post[]= 'select';
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cat_post[$category->slug] = $category->name;
    }

    $wp_customize->add_setting('indoor_sports_zone_services_sec_category',array(
        'default'   => 'select',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_select',
    ));
    $wp_customize->add_control('indoor_sports_zone_services_sec_category',array(
        'type'    => 'select',
        'choices' => $cat_post,
        'label' => __('Select Category to display Services','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_services_section',
    ));

    // Pro Version
    $wp_customize->add_setting( 'indoor_sports_zone_service_setting', array(
        'sanitize_callback' => 'Indoor_Sports_Zone_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Indoor_Sports_Zone_Customize_Pro_Version ( $wp_customize,'indoor_sports_zone_service_setting', array(
        'section'     => 'indoor_sports_zone_services_section',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'indoor-sports-zone' ),
        'description' => esc_url( INDOOR_SPORTS_ZONE_URL ),
        'priority'    => 100
    )));

    // Post Settings
     $wp_customize->add_section('indoor_sports_zone_post_settings',array(
        'title' => esc_html__('Post Settings','indoor-sports-zone'),
        'priority'   =>40,
    ));

    $wp_customize->add_setting('indoor_sports_zone_post_page_title',array(
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('indoor_sports_zone_post_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Title', 'indoor-sports-zone'),
        'section'     => 'indoor_sports_zone_post_settings',
        'description' => esc_html__('Check this box to enable title on post page.', 'indoor-sports-zone'),
    ));

    $wp_customize->add_setting('indoor_sports_zone_post_page_content',array(
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('indoor_sports_zone_post_page_content',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Content', 'indoor-sports-zone'),
        'section'     => 'indoor_sports_zone_post_settings',
        'description' => esc_html__('Check this box to enable content on post page.', 'indoor-sports-zone'),
    ));

    // Single Post Page Settings
    $wp_customize->add_setting( 'indoor_sports_zone_single_post_page_image_border_radius', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'indoor_sports_zone_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'indoor_sports_zone_single_post_page_image_border_radius', array(
        'label'       => esc_html__( 'Single Post Page Image Border Radius','indoor-sports-zone' ),
        'section'     => 'indoor_sports_zone_post_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    $wp_customize->add_setting( 'indoor_sports_zone_single_post_page_image_box_shadow', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'indoor_sports_zone_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'indoor_sports_zone_single_post_page_image_box_shadow', array(
        'label'       => esc_html__( 'Single Post Page Image Box Shadow','indoor-sports-zone' ),
        'section'     => 'indoor_sports_zone_post_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    $wp_customize->add_setting('indoor_sports_zone_single_post_page_content',array(
        'sanitize_callback' => 'indoor_sports_zone_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('indoor_sports_zone_single_post_page_content',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Page Content', 'indoor-sports-zone'),
        'section'     => 'indoor_sports_zone_post_settings',
        'description' => esc_html__('Check this box to enable content on single post page.', 'indoor-sports-zone'),
    ));
    
    // Footer
    $wp_customize->add_section('indoor_sports_zone_site_footer_section', array(
        'title' => esc_html__('Footer', 'indoor-sports-zone'),
    ));

    $wp_customize->add_setting('indoor_sports_zone_footer_bg_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'indoor_sports_zone_footer_bg_image',array(
        'label' => __('Footer Background Image','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_site_footer_section',
        'priority' => 1,
    )));

    $wp_customize->add_setting('indoor_sports_zone_footer_bg_image_position',array(
        'default'=> 'scroll',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_footer_bg_image_position',array(
        'type' => 'select',
        'label' => __('Footer Background Image Position','indoor-sports-zone'),
        'choices' => array(
            'fixed' => __('fixed','indoor-sports-zone'),
            'scroll' => __('scroll','indoor-sports-zone'),
        ),
        'section'=> 'indoor_sports_zone_site_footer_section',
    ));

    $wp_customize->add_setting('indoor_sports_zone_footer_widget_heading_alignment',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_footer_widget_heading_alignment',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading Alignment','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_site_footer_section',
        'choices' => array(
            'Left' => __('Left','indoor-sports-zone'),
            'Center' => __('Center','indoor-sports-zone'),
            'Right' => __('Right','indoor-sports-zone')
        ),
    ) );

    $wp_customize->add_setting('indoor_sports_zone_footer_widget_content_alignment',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_footer_widget_content_alignment',array(
        'type' => 'select',
        'label' => __('Footer Widget Content Alignment','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_site_footer_section',
        'choices' => array(
            'Left' => __('Left','indoor-sports-zone'),
            'Center' => __('Center','indoor-sports-zone'),
            'Right' => __('Right','indoor-sports-zone')
        ),
    ) );

    $wp_customize->add_setting('indoor_sports_zone_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('indoor_sports_zone_footer_text_setting', array(
        'label' => __('Replace the footer text', 'indoor-sports-zone'),
        'section' => 'indoor_sports_zone_site_footer_section',
        'type' => 'text',
    ));

    $wp_customize->add_setting('indoor_sports_zone_copyright_content_alignment',array(
        'default' => 'Center',
        'transport' => 'refresh',
        'sanitize_callback' => 'indoor_sports_zone_sanitize_choices'
    ));
    $wp_customize->add_control('indoor_sports_zone_copyright_content_alignment',array(
        'type' => 'select',
        'label' => __('Copyright Content Alignment','indoor-sports-zone'),
        'section' => 'indoor_sports_zone_site_footer_section',
        'choices' => array(
            'Left' => __('Left','indoor-sports-zone'),
            'Center' => __('Center','indoor-sports-zone'),
            'Right' => __('Right','indoor-sports-zone')
        ),
    ) );

    // Pro Version
    $wp_customize->add_setting( 'indoor_sports_zone_footer_setting', array(
        'sanitize_callback' => 'Indoor_Sports_Zone_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Indoor_Sports_Zone_Customize_Pro_Version ( $wp_customize,'indoor_sports_zone_footer_setting', array(
        'section'     => 'indoor_sports_zone_site_footer_section',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'indoor-sports-zone' ),
        'description' => esc_url( INDOOR_SPORTS_ZONE_URL ),
        'priority'    => 100
    )));
}
add_action('customize_register', 'indoor_sports_zone_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function indoor_sports_zone_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function indoor_sports_zone_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function indoor_sports_zone_customize_preview_js(){
    wp_enqueue_script('indoor-sports-zone-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'indoor_sports_zone_customize_preview_js');

/*
** Load dynamic logic for the customizer controls area.
*/
function indoor_sports_zone_panels_js() {
    wp_enqueue_style( 'indoor-sports-zone-customizer-layout-css', get_theme_file_uri( '/assets/css/customizer-layout.css' ) );
    wp_enqueue_script( 'indoor-sports-zone-customize-layout', get_theme_file_uri( '/assets/js/customize-layout.js' ), array(), '1.2', true );
}
add_action( 'customize_controls_enqueue_scripts', 'indoor_sports_zone_panels_js' );